Index: gli/trunk/src/org/greenstone/gatherer/collection/CollectionManager.java
===================================================================
--- gli/trunk/src/org/greenstone/gatherer/collection/CollectionManager.java	(revision 14817)
+++ gli/trunk/src/org/greenstone/gatherer/collection/CollectionManager.java	(revision 14974)
@@ -159,5 +159,27 @@
 	    command_parts_list.add("-S");
 	}
-	command_parts_list.add(LocalGreenstone.getBinScriptDirectoryPath() + "buildcol.pl");
+
+	if (Configuration.fedora_info.isActive()) {
+	    command_parts_list.add(LocalGreenstone.getBinScriptDirectoryPath() + "g2f-buildcol.pl");
+
+	    command_parts_list.add("-hostname");
+	    command_parts_list.add(Configuration.fedora_info.getHostname());
+
+	    command_parts_list.add("-port");
+	    command_parts_list.add(Configuration.fedora_info.getPort());
+
+	    command_parts_list.add("-username");
+	    command_parts_list.add(Configuration.fedora_info.getUsername());
+
+	    command_parts_list.add("-password");
+	    command_parts_list.add(Configuration.fedora_info.getPassword());
+
+	    command_parts_list.add("-protocol");
+	    command_parts_list.add(Configuration.fedora_info.getProtocol());
+
+	}
+	else {
+	    command_parts_list.add(LocalGreenstone.getBinScriptDirectoryPath() + "buildcol.pl");
+	}
 	command_parts_list.add("-gli");
 	command_parts_list.add("-language");
@@ -193,8 +215,23 @@
     public boolean built() {
 	if(collection != null) {
-	    // Determine if the collection has been built by looking for the build.cfg or buildConfig.xml file
-	    String file_name = (Gatherer.GS3)? Utility.BUILD_CONFIG_XML : Utility.BUILD_CFG;
-	    File build_cfg_file = new File(getLoadedCollectionIndexDirectoryPath() + file_name);
-	    return build_cfg_file.exists();
+	    // Determine if the collection has been built by looking for the build.cfg (gs20 buildConfig.xml (gs3) or export.inf (fedora) file
+	    String file_name = "";
+
+	    if (Gatherer.GS3) {
+		file_name = getLoadedCollectionIndexDirectoryPath() + Utility.BUILD_CONFIG_XML;
+	    }
+	    else {
+		if (Configuration.fedora_info.isActive()) {
+		    // Fedora build
+		    //file_name = getLoadedCollectionArchivesDirectoryPath() + "import.inf";
+		    file_name = getLoadedCollectionExportDirectoryPath() + "export.inf";
+		}
+		else {
+		    file_name = getLoadedCollectionIndexDirectoryPath() + Utility.BUILD_CFG;
+		}
+	    }
+
+	    File test_file = new File(file_name);
+	    return test_file.exists();
 	}
 	return false;
@@ -592,4 +629,12 @@
     }
 
+    /** Returns the absolute filename of the loaded collection's export directory.
+     */
+    static public String getLoadedCollectionExportDirectoryPath()
+    {
+	return getLoadedCollectionDirectoryPath() + "export" + File.separator;
+    }
+
+
 
     /** Returns the absolute filename of the loaded collection's building directory.
@@ -764,5 +809,27 @@
 	    command_parts_list.add("-S");
 	}
-	command_parts_list.add(LocalGreenstone.getBinScriptDirectoryPath() + "import.pl");
+
+	if (Configuration.fedora_info.isActive()) {
+	    command_parts_list.add(LocalGreenstone.getBinScriptDirectoryPath() + "g2f-import.pl");
+
+	    command_parts_list.add("-hostname");
+	    command_parts_list.add(Configuration.fedora_info.getHostname());
+
+	    command_parts_list.add("-port");
+	    command_parts_list.add(Configuration.fedora_info.getPort());
+
+	    command_parts_list.add("-username");
+	    command_parts_list.add(Configuration.fedora_info.getUsername());
+
+	    command_parts_list.add("-password");
+	    command_parts_list.add(Configuration.fedora_info.getPassword());
+
+	    command_parts_list.add("-protocol");
+	    command_parts_list.add(Configuration.fedora_info.getProtocol());
+	}
+	else {
+	    command_parts_list.add(LocalGreenstone.getBinScriptDirectoryPath() + "import.pl");
+	}
+
 	command_parts_list.add("-gli");
 	command_parts_list.add("-language");
@@ -1339,4 +1406,10 @@
     private boolean installCollection()
     {
+	if (Configuration.fedora_info.isActive()) {
+	    DebugStream.println("Fedora build complete. No need to move files.");
+	    return true;
+	}
+
+       
 	DebugStream.println("Build complete. Moving files.");
 
